@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2
-id: yesod-1.4.2-430356a86de00bd7f1d5c2fed0b49f35
-key: yesod_KKqDIWk4CWb67ekaY5TACl
+id: yesod-1.4.2-1b35010312ab419b61f60d2144436df2
+key: yesod_2WbcnXHQpNOIH4Oluk4mE4
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,19 +21,19 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
-hs-libraries: HSyesod-1.4.2-KKqDIWk4CWb67ekaY5TACl
+hs-libraries: HSyesod-1.4.2-2WbcnXHQpNOIH4Oluk4mE4
 depends:
     aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
     blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-extra-1.1.9.2-a8df29ae092d8bac0881b0dcd304f6e0
+    conduit-extra-1.1.9.2-79e9518024a2df5c3adcf7d7df9fbea5
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
-    monad-control-1.0.0.4-fa18b603f1c859e06ea8fbebdf00a3e7
-    monad-logger-0.3.17-2474786aa3115e9241bf408968531d43
+    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
+    monad-logger-0.3.17-d3b65fae3959e41c01434c1c220af3fd
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     semigroups-0.18.1-34c490e60d2f8a8cae75b79e944c6c08
     shakespeare-2.0.7-3d8247ff57d7f10558308bd73d118ae2
@@ -44,14 +44,14 @@ depends:
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
     wai-3.2.0-ef5213f36cb00369a3d68c2dd00424b9
-    wai-extra-3.0.13.1-b46007781e2a041882ada622855f7e6a
+    wai-extra-3.0.13.1-2dd6d778b5d3c8057ac149701ac5c371
     wai-logger-2.2.4.1-78754ae80b1823d94a638e54c94b2c6e
     warp-3.2.1-8f9aad771e0c137389da779f459b244d
-    yaml-0.8.15.3-18fe551db9317314e9733a6c27b37de0
-    yesod-auth-1.4.12-acd7b4aded7aef538f208b08f6f164e0
-    yesod-core-1.4.19-daae9b98d9ea7cd0454523fd27911d74
-    yesod-form-1.4.6-9bddbdc8b6f91062e995daf02cfa5ebd
-    yesod-persistent-1.4.0.3-c093a8bbfb454274e63e03ec1211a970
+    yaml-0.8.15.3-3d6bb92af78b0dac755a8e256ace903e
+    yesod-auth-1.4.12-1bd872bb0b3bb50f84405f03c3060b46
+    yesod-core-1.4.19-516d05f0f7a24f16b48a3d78a1b5e378
+    yesod-form-1.4.6-4e51451ad8a0ff5cee562f45fede6545
+    yesod-persistent-1.4.0.3-e292066aa899804c642be44b1d89205f
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
